@@ -35,13 +35,18 @@ void GoogleDrivePlugin::onAccountCreated(const Accounts::AccountId accountId, co
     notification->setComponentName(QStringLiteral("gdrive"));
     notification->setTitle(i18n("New Online Account"));
     notification->setText(xi18nc("@info", "You can now manage the Google Drive files of your <emphasis strong='true'>%1</emphasis> account.", account->displayName()));
-    notification->setActions({i18n("Open")});
 
     QUrl url;
     url.setScheme(QStringLiteral("gdrive"));
     url.setPath(QStringLiteral("/%1").arg(account->displayName()));
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    notification->setActions({i18n("Open")});
     connect(notification, static_cast<void (KNotification::*)(unsigned int)>(&KNotification::activated), this, [=]() {
+#else
+    auto action = notification->addAction(i18n("Open"));
+    connect(action, &KNotificationAction::activated, this, [url] {
+#endif
         KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, QStringLiteral("inode/directory"));
         job->start();
     });
